/* TB6560AHG */

#include <Bounce.h>

#define LED   13

#define CLK_M1    11
#define RESET_M1  10
#define ENABLE_M1  9
#define CWCCW_M1   8
#define TQ1_M1     7
#define TQ2_M1     6

#define CLK_M2     5
#define RESET_M2   4
#define ENABLE_M2  3
#define CWCCW_M2   2
#define TQ1_M2     1
#define TQ2_M2     0

#define SW1       14
#define SW2       15
#define SW3       16

#define SW_ON     LOW
#define SW_OFF    HIGH

#define MOTOR_STOP 0
#define MOTOR_RUN  1

#define CCW      HIGH
#define CW       LOW

int motor1_stat = MOTOR_STOP;
int motor2_stat = MOTOR_STOP;
int motor_rotate = CCW;

unsigned long time,ptime;

Bounce bouncerSW1 = Bounce( SW1, 5 );
Bounce bouncerSW2 = Bounce( SW2, 5 );
Bounce bouncerSW3 = Bounce( SW3, 5 );

void setup()   {                
  pinMode(LED, OUTPUT);  
  
  pinMode(CLK_M1,    OUTPUT);     
  pinMode(RESET_M1,  OUTPUT);     
  pinMode(ENABLE_M1, OUTPUT);     
  pinMode(CWCCW_M1,  OUTPUT);
  pinMode(TQ1_M1,    OUTPUT);
  pinMode(TQ2_M1,    OUTPUT);

  pinMode(CLK_M2,    OUTPUT);     
  pinMode(RESET_M2,  OUTPUT);     
  pinMode(ENABLE_M2, OUTPUT);     
  pinMode(CWCCW_M2,  OUTPUT);
  pinMode(TQ1_M2,    OUTPUT);
  pinMode(TQ2_M2,    OUTPUT);

  pinMode(SW1, INPUT);
  pinMode(SW2, INPUT);
  pinMode(SW3, INPUT);
  
  digitalWrite(TQ1_M1, LOW ); // 100%
  digitalWrite(TQ2_M1, LOW ); // 100%
  digitalWrite(TQ1_M2, LOW ); // 100%
  digitalWrite(TQ2_M2, LOW ); // 100%
  
  
  init_motor( 1 );
  init_motor( 2 );
}


void loop()                     
{
  if ( bouncerSW1.update() ) {
    if ( bouncerSW1.read() == HIGH) {
      if ( motor1_stat == MOTOR_STOP ) {
        motor1_stat = MOTOR_RUN;
        init_motor( 1 );
      } else {
        motor1_stat = MOTOR_STOP;
        stop_motor( 1 );
      }
    }
  }

  if ( bouncerSW2.update() ) {
    if ( bouncerSW2.read() == HIGH) {
      if ( motor2_stat == MOTOR_STOP ) {
        motor2_stat = MOTOR_RUN;
        init_motor( 2 );
      } else {
        motor2_stat = MOTOR_STOP;
        stop_motor( 2 );
      }
    }
  }

  if ( bouncerSW3.update() ) {
    if ( bouncerSW3.read() == HIGH) {
      if ( motor_rotate == CCW ) {
        motor_rotate = CW;
        digitalWrite(CWCCW_M1, CW);
        digitalWrite(CWCCW_M2, CW);
      } else {
        motor_rotate = CCW;
        digitalWrite(CWCCW_M1, CCW);
        digitalWrite(CWCCW_M2, CCW);
      }
    }
  }

  delayMicroseconds(60);
  if( motor1_stat == MOTOR_RUN ) {  
    digitalWrite(CLK_M1, HIGH);
  }
  if( motor2_stat == MOTOR_RUN ) {  
    digitalWrite(CLK_M2, HIGH);
  }
  delayMicroseconds(60);
  if( motor1_stat == MOTOR_RUN ) {  
    digitalWrite(CLK_M1, LOW);
  }
  if( motor2_stat == MOTOR_RUN ) {  
    digitalWrite(CLK_M2, LOW);
  }
}

void init_motor(int motor_No)
{
  switch( motor_No ) {
    case 1:
      digitalWrite( RESET_M1,  LOW );
      digitalWrite( ENABLE_M1, LOW );
      digitalWrite( CWCCW_M1,  CCW );
      delay(100);
      digitalWrite( ENABLE_M1, HIGH );
      delay(100);
      digitalWrite( RESET_M1,  HIGH );
      delay(100);
      break;
    case 2:
      digitalWrite( RESET_M2,  LOW );
      digitalWrite( ENABLE_M2, LOW );
      digitalWrite( CWCCW_M2,  CCW );
      delayMicroseconds(100);
      digitalWrite( ENABLE_M2, HIGH );
      delayMicroseconds(100);
      digitalWrite( RESET_M2,  HIGH );
      delayMicroseconds(100);
      break;
  }
}

void stop_motor( int motor_No )
{
  switch( motor_No ) {
    case 1:
      digitalWrite( RESET_M1,  LOW );
      digitalWrite( ENABLE_M1, LOW );
      break;
    case 2:
      digitalWrite( RESET_M2,  LOW );
      digitalWrite( ENABLE_M2, LOW );   
      break;
  }
}

